@@ -538,6 +538,45 @@ class ItemUploader(object):
                     time.sleep(mdelay)
                     mdelay *= backoff
 
+    def upload_rows(
+        self, rows, priority=0, pipeline_workflow_id=None,
+    ):
+        """Sends ``rows`` to Squirro.
+
+        :param rows: A list of rows. Row means a single row of data that will eventually
+            transformed, enriched, and become a Squirro item. In other words, a row is a
+            single data point/sample of raw data.
+        :param priority: int, describing the priority of ingestion for the dataset to be
+            loaded. Currently only supports a value of `0` or `1`.
+            `0` means that the items are loaded in an asynchronous fashion and
+            `1` would mean that the items are loaded in a synchronous fashion.
+        :param pipeline_workflow_id: str, id of an existing pipeline workflow which
+            should be used to process the current batch of items. Can only be used with
+            parameter `priority` set to 1.
+        """
+        self._validate_upload_parameters(priority, pipeline_workflow_id)
+        if not self.config.get("provider_api_url"):
+            cluster = self.config["cluster"]
+            url = "{0}/api/provider/v1/{1}/projects/{2}/sources/{3}/push_rows".format(
+                cluster, self.client.tenant, self.project_id, self.source_id
+            )
+        else:
+            endpoint = self.config["provider_api_url"]
+            url = "{0}/v1/{1}/projects/{2}/sources/{3}/push_rows".format(
+                endpoint, self.client.tenant, self.project_id, self.source_id
+            )
+        headers = {"Content-Type": "application/json"}
+        params = {"priority": priority}
+        if pipeline_workflow_id is not None:
+            params.update({"pipeline_workflow_id": pipeline_workflow_id})
+
+        data = json.dumps(rows)
+
+        res = self.client._perform_request(
+            "post", url, params=params, data=data, headers=headers
+        )
+        self.client._process_response(res)
+
     def _validate_upload_parameters(self, priority, pipeline_workflow_id):
         """Validations for parameters to the `upload` function."""
         if priority != 1 and pipeline_workflow_id:
