@@ -7,12 +7,14 @@ class PipelineWorkflowMixin(object):
     # Pipeline Workflows
     #
 
-    def get_pipeline_workflows(self, project_id, omit_steps=False):
+    def get_pipeline_workflows(self, project_id, omit_steps=False, omit_sources=False):
         """Return all pipeline workflows for project with `project_id`.
 
         :param project_id: id of the project within tenant
         :param omit_steps: whether to omit steps in the response for better
             performance
+        :param omit_sources: whether to omit in the response the data sources which are
+        configured to use each pipeline workflow
         :return: A list of pipeline workflow dictionaries.
 
         Example::
@@ -50,7 +52,7 @@ class PipelineWorkflowMixin(object):
             "project_id": project_id,
         }
 
-        data_dict = dict(omit_steps=omit_steps)
+        data_dict = dict(omit_steps=omit_steps, omit_sources=omit_sources)
 
         res = self._perform_request(
             "get", url, data=json.dumps(data_dict), headers=headers
@@ -58,7 +60,9 @@ class PipelineWorkflowMixin(object):
 
         return self._process_response(res)
 
-    def get_pipeline_workflow(self, project_id, workflow_id, omit_steps=False):
+    def get_pipeline_workflow(
+        self, project_id, workflow_id, omit_steps=False, omit_sources=False
+    ):
         """Return a specific pipeline workflow `workflow_id` in project with
         `project_id`.
 
@@ -66,6 +70,8 @@ class PipelineWorkflowMixin(object):
         :param workflow_id: pipeline workflow id
         :param omit_steps: whether to omit steps in the response for better
             performance
+        :param omit_sources: whether to omit in the response the data sources which are
+        configured to use this pipeline workflow
         :return: A dictionary of the pipeline workflow.
 
         Example::
@@ -102,7 +108,7 @@ class PipelineWorkflowMixin(object):
             }
         )
 
-        data_dict = dict(omit_steps=omit_steps)
+        data_dict = dict(omit_steps=omit_steps, omit_sources=omit_sources)
 
         res = self._perform_request(
             "get", url, data=json.dumps(data_dict), headers=headers
@@ -277,3 +283,25 @@ class PipelineWorkflowMixin(object):
         )
 
         return self._process_response(res, [202])
+
+    def get_pipeline_workflows_presets(self, project_id):
+        """Return a list of pre-made pipeline workflows for covering various use cases.
+
+        :param project_id: the Id of the project
+        :return: a list of dictionaries where each dictionary represents a pipeline
+        workflow preset.
+        """
+        headers = {"Accept": "application/json"}
+
+        url = (
+            "%(ep)s/v0/%(tenant)s/projects/%(project_id)s/pipeline_workflows/presets"
+            % {
+                "ep": self.topic_api_url,
+                "tenant": self.tenant,
+                "project_id": project_id,
+            }
+        )
+
+        res = self._perform_request("get", url, headers=headers)
+
+        return self._process_response(res)
